Author: Petre Iordanescu (petre.iordanescu@gmail.com)

Skip to content

# BookLab

by RENware Software Systems

Welcome to BookLab world, your personal assistant in putting your ideas in practice and making your books as you dreamed them.

Bine ai venit in lunea BookLab, asistentul tau personal in punerea ideilor tale in practica si realizarea cartlior si materialelor tale asa cum le-ai visat.

Ce poti face mai departe:

- sa vezi catalogul cartilor tale
- sa incepi o noua carte

Daca inca nu esti sigur sau hotarit, poti sa revezi doumentatia sistemului:

- sa citesti "Vederea de ansamblu" a BookLab
- sa revezi manualele de utilizare
- sa revezi manualele de configurare

Versiunea publica demo

Versiunea publica (demonstrativa) a aplicatiei Booklab (accesibila la adresa `booklab.renware.eu`) are scop pur demonstrativ. In aceaata aplicatie se pot face teste in mod public si neidentificat (anonim) drept pentru care puteti gasi diverse date / carti create de catre alte persoane decit dumneavoastra. De aceea va rugam sa nu alterati carti sau date care nu stiti ca le-ati creat dumneavostra. Creati-va propriile carti asupra carora sa faceti orice teste dorite.

Last update: September 24, 2025